@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use URI;
 use base qw(WebService::Simple);
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 __PACKAGE__->config(
 		base_url => 'http://yahooapis.jp/',
 		);
@@ -90,13 +90,14 @@ WebService::Simple::Yahoo::JP::API - Simple Interface to Yahoo! JAPAN Web APIs
   use WebService::Simple::Yahoo::JP::API;
   use WebService::Simple::Yahoo::JP::API::Search;
   my $xs = XML::Simple->new( KeyAttr => [], ForceArray => ['Result'] );
-  my $appid = 'hY5jLiqxg667n_2_Ho0Q6L_tRQWDeZT93fTG234MEQUk_eIfu7Q7_Uv48dZB';
+  my $appid = '************************************************************';
   my $api = WebService::Simple::Yahoo::JP::API->new(
-  appid => $appid,
-  response_parser => WebService::Simple::Parser::XML::Simple->new(xs => $xs),
+    appid => $appid,
+    response_parser => WebService::Simple::Parser::XML::Simple->new(xs => $xs),
   );
   my $res = $api->search->websearch(query => "Perl");
   print Dumper $res;
+  print Dumper $res->parse_response;
 
 =head1 DESCRIPTION
 
